@@ -341,6 +341,11 @@ def iter_nodes(
             yield NodeInfo(tuple(stack), node)
 
 
+def iter_all_nodes(ast, recursive=True) -> Iterator[NodeInfo]:
+    for stack, node in _iter_nodes(ast, recursive=recursive):
+        yield NodeInfo(tuple(stack), node)
+
+
 def is_library_node_info(node_info: NodeInfo) -> bool:
     return node_info.node.__class__.__name__ in LIBRARY_IMPORT_CLASSES
 
@@ -449,8 +454,9 @@ def create_keyword_usage_info(stack, node) -> Optional[KeywordUsageInfo]:
 
     elif isinstance_name(node, ("Fixture", "TestTemplate")):
         node, token = _strip_node_and_token_bdd_prefix(node, Token.NAME)
-        keyword_name = token.value
-        return KeywordUsageInfo(tuple(stack), node, token, keyword_name)
+        if token is not None:
+            keyword_name = token.value
+            return KeywordUsageInfo(tuple(stack), node, token, keyword_name)
 
     return None
 
@@ -522,6 +528,8 @@ def _strip_node_and_token_bdd_prefix(node, token_type):
     we can stop doing this.
     """
     original_token = node.get_token(token_type)
+    if original_token is None:
+        return node, None
     token = _strip_token_bdd_prefix(original_token)
     if token is original_token:
         # i.e.: No change was done.
